summaryrefslogtreecommitdiff
path: root/perl
diff options
context:
space:
mode:
authorRuss Allbery <eagle@eyrie.org>2014-04-13 16:36:36 -0700
committerRuss Allbery <rra@stanford.edu>2014-04-13 16:37:25 -0700
commit76ccf098c6e9c8849c8ca459a54d7383baf39ddb (patch)
tree8e955c0b86954a3db67dccd75e8cefdfd0d0b636 /perl
parent401bfdd941e55651f38f46b76b297968691fcaf3 (diff)
Change my email address to eagle@eyrie.org
Change-Id: I4c2b5d7c807d6c27dd18a3b92eef66d21287d21e Reviewed-on: https://gerrit.stanford.edu/1481 Reviewed-by: Russ Allbery <rra@stanford.edu> Tested-by: Russ Allbery <rra@stanford.edu>
Diffstat (limited to 'perl')
-rw-r--r--perl/Makefile.PL.in2
-rw-r--r--perl/Wallet/ACL.pm4
-rw-r--r--perl/Wallet/ACL/Base.pm4
-rw-r--r--perl/Wallet/ACL/Krb5.pm4
-rw-r--r--perl/Wallet/ACL/Krb5/Regex.pm2
-rw-r--r--perl/Wallet/ACL/LDAP/Attribute.pm2
-rw-r--r--perl/Wallet/ACL/NetDB.pm4
-rw-r--r--perl/Wallet/ACL/NetDB/Root.pm4
-rw-r--r--perl/Wallet/Admin.pm4
-rw-r--r--perl/Wallet/Config.pm4
-rw-r--r--perl/Wallet/Database.pm4
-rw-r--r--perl/Wallet/Kadmin.pm2
-rw-r--r--perl/Wallet/Kadmin/Heimdal.pm2
-rw-r--r--perl/Wallet/Kadmin/MIT.pm4
-rw-r--r--perl/Wallet/Object/Base.pm4
-rw-r--r--perl/Wallet/Object/File.pm4
-rw-r--r--perl/Wallet/Object/Keytab.pm4
-rw-r--r--perl/Wallet/Object/WAKeyring.pm4
-rw-r--r--perl/Wallet/Policy/Stanford.pm4
-rw-r--r--perl/Wallet/Report.pm4
-rw-r--r--perl/Wallet/Schema.pm2
-rw-r--r--perl/Wallet/Server.pm4
-rwxr-xr-xperl/t/acl.t2
-rwxr-xr-xperl/t/admin.t2
-rwxr-xr-xperl/t/config.t2
-rwxr-xr-xperl/t/file.t2
-rwxr-xr-xperl/t/init.t2
-rwxr-xr-xperl/t/keytab.t2
-rw-r--r--perl/t/lib/Util.pm2
-rwxr-xr-xperl/t/object.t2
-rwxr-xr-xperl/t/pod-spelling.t2
-rwxr-xr-xperl/t/pod.t2
-rwxr-xr-xperl/t/report.t2
-rwxr-xr-xperl/t/server.t2
-rwxr-xr-xperl/t/stanford-naming.t2
-rwxr-xr-xperl/t/verifier-ldap-attr.t4
-rwxr-xr-xperl/t/verifier-netdb.t4
-rwxr-xr-xperl/t/verifier.t20
-rwxr-xr-xperl/t/wa-keyring.t2
39 files changed, 66 insertions, 66 deletions
diff --git a/perl/Makefile.PL.in b/perl/Makefile.PL.in
index 5804d9b..a3038ae 100644
--- a/perl/Makefile.PL.in
+++ b/perl/Makefile.PL.in
@@ -12,7 +12,7 @@ WriteMakefile(
NAME => 'Wallet',
VERSION => $version,
ABSTRACT => 'Wallet: a secure credential management system',
- AUTHOR => 'Russ Allbery (rra@stanford.edu)',
+ AUTHOR => 'Russ Allbery (eagle@eyrie.org)',
(($prefix ne '/usr' && $prefix ne '/usr/local') ?
(PREFIX => $prefix) : ())
);
diff --git a/perl/Wallet/ACL/Krb5/Regex.pm b/perl/Wallet/ACL/Krb5/Regex.pm
index ce2fe48..30f5527 100644
--- a/perl/Wallet/ACL/Krb5/Regex.pm
+++ b/perl/Wallet/ACL/Krb5/Regex.pm
@@ -1,6 +1,6 @@
# Wallet::ACL::Krb5::Regex -- Wallet Kerberos v5 principal regex ACL verifier
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2010
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/Wallet/ACL/LDAP/Attribute.pm b/perl/Wallet/ACL/LDAP/Attribute.pm
index 31001ea..aea8a72 100644
--- a/perl/Wallet/ACL/LDAP/Attribute.pm
+++ b/perl/Wallet/ACL/LDAP/Attribute.pm
@@ -258,6 +258,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
diff --git a/perl/Wallet/Kadmin.pm b/perl/Wallet/Kadmin.pm
index bfff3ef..4ea7920 100644
--- a/perl/Wallet/Kadmin.pm
+++ b/perl/Wallet/Kadmin.pm
@@ -235,6 +235,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHORS
-Jon Robertson <jonrober@stanford.edu> and Russ Allbery <rra@stanford.edu>
+Jon Robertson <jonrober@stanford.edu> and Russ Allbery <eagle@eyrie.org>
=cut
diff --git a/perl/Wallet/Kadmin/Heimdal.pm b/perl/Wallet/Kadmin/Heimdal.pm
index a1d63ae..42de8e0 100644
--- a/perl/Wallet/Kadmin/Heimdal.pm
+++ b/perl/Wallet/Kadmin/Heimdal.pm
@@ -309,6 +309,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHORS
-Russ Allbery <rra@stanford.edu> and Jon Robertson <jonrober@stanford.edu>.
+Russ Allbery <eagle@eyrie.org> and Jon Robertson <jonrober@stanford.edu>.
=cut
diff --git a/perl/Wallet/Schema.pm b/perl/Wallet/Schema.pm
index d4ef241..2176cab 100644
--- a/perl/Wallet/Schema.pm
+++ b/perl/Wallet/Schema.pm
@@ -334,6 +334,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
diff --git a/perl/t/acl.t b/perl/t/acl.t
index 26b4903..7265865 100755
--- a/perl/t/acl.t
+++ b/perl/t/acl.t
@@ -2,7 +2,7 @@
#
# Tests for the wallet ACL API.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/admin.t b/perl/t/admin.t
index 740c79e..1f3ccba 100755
--- a/perl/t/admin.t
+++ b/perl/t/admin.t
@@ -2,7 +2,7 @@
#
# Tests for wallet administrative interface.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2008, 2009, 2010, 2011, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/config.t b/perl/t/config.t
index 543e5d6..881f2bd 100755
--- a/perl/t/config.t
+++ b/perl/t/config.t
@@ -2,7 +2,7 @@
#
# Tests for the wallet server configuration.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2008, 2010
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/file.t b/perl/t/file.t
index 5cb7c35..ac35c44 100755
--- a/perl/t/file.t
+++ b/perl/t/file.t
@@ -2,7 +2,7 @@
#
# Tests for the file object implementation.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2008
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/init.t b/perl/t/init.t
index 142f54c..189a689 100755
--- a/perl/t/init.t
+++ b/perl/t/init.t
@@ -2,7 +2,7 @@
#
# Tests for database initialization.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/keytab.t b/perl/t/keytab.t
index 34da9c9..cb256ee 100755
--- a/perl/t/keytab.t
+++ b/perl/t/keytab.t
@@ -2,7 +2,7 @@
#
# Tests for the keytab object implementation.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008, 2009, 2010, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/lib/Util.pm b/perl/t/lib/Util.pm
index 3e606fe..9e5b95e 100644
--- a/perl/t/lib/Util.pm
+++ b/perl/t/lib/Util.pm
@@ -1,6 +1,6 @@
# Utility class for wallet tests.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/object.t b/perl/t/object.t
index 5eb6941..12443bc 100755
--- a/perl/t/object.t
+++ b/perl/t/object.t
@@ -2,7 +2,7 @@
#
# Tests for the basic object implementation.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008, 2011
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/pod-spelling.t b/perl/t/pod-spelling.t
index 6d9f7b0..577a99e 100755
--- a/perl/t/pod-spelling.t
+++ b/perl/t/pod-spelling.t
@@ -7,7 +7,7 @@
# RRA_MAINTAINER_TESTS is set, since spelling dictionaries vary too much
# between environments.
#
-# Copyright 2008, 2009 Russ Allbery <rra@stanford.edu>
+# Copyright 2008, 2009 Russ Allbery <eagle@eyrie.org>
#
# See LICENSE for licensing terms.
diff --git a/perl/t/pod.t b/perl/t/pod.t
index dc5f468..dfcf88e 100755
--- a/perl/t/pod.t
+++ b/perl/t/pod.t
@@ -2,7 +2,7 @@
#
# Test POD formatting for the wallet Perl modules.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2010
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/report.t b/perl/t/report.t
index a6b85df..4ea9628 100755
--- a/perl/t/report.t
+++ b/perl/t/report.t
@@ -2,7 +2,7 @@
#
# Tests for the wallet reporting interface.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2008, 2009, 2010
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/server.t b/perl/t/server.t
index 4afda51..2a83008 100755
--- a/perl/t/server.t
+++ b/perl/t/server.t
@@ -2,7 +2,7 @@
#
# Tests for the wallet server API.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008, 2010, 2011, 2012, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/stanford-naming.t b/perl/t/stanford-naming.t
index f222c49..c512ad0 100755
--- a/perl/t/stanford-naming.t
+++ b/perl/t/stanford-naming.t
@@ -6,7 +6,7 @@
# sites, but it's used at Stanford and this test suite is used to verify
# behavior at Stanford.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2013
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/t/verifier-ldap-attr.t b/perl/t/verifier-ldap-attr.t
index 7fad990..37a8b92 100755
--- a/perl/t/verifier-ldap-attr.t
+++ b/perl/t/verifier-ldap-attr.t
@@ -5,7 +5,7 @@
# This test can only be run by someone local to Stanford with appropriate
# access to the LDAP server and will be skipped in all other environments.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2012, 2013, 2014
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -28,7 +28,7 @@ require_ok ('Wallet::ACL::LDAP::Attribute');
my $host = 'ldap.stanford.edu';
my $base = 'cn=people,dc=stanford,dc=edu';
my $filter = 'uid';
-my $user = 'rra@stanford.edu';
+my $user = 'eagle@eyrie.org';
my $attr = 'suPrivilegeGroup';
my $value = 'stanford:stanford';
diff --git a/perl/t/verifier-netdb.t b/perl/t/verifier-netdb.t
index 398cc6a..3e34966 100755
--- a/perl/t/verifier-netdb.t
+++ b/perl/t/verifier-netdb.t
@@ -6,7 +6,7 @@
# access to the NetDB role server and will be skipped in all other
# environments.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2008
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -21,7 +21,7 @@ use Util;
my $netdb = 'netdb-node-roles-rc.stanford.edu';
my $host = 'windlord.stanford.edu';
-my $user = 'rra@stanford.edu';
+my $user = 'eagle@eyrie.org';
# Determine the local principal.
my $klist = `klist 2>&1` || '';
diff --git a/perl/t/verifier.t b/perl/t/verifier.t
index 75f1afa..c734762 100755
--- a/perl/t/verifier.t
+++ b/perl/t/verifier.t
@@ -2,7 +2,7 @@
#
# Tests for the basic wallet ACL verifiers.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008, 2010
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -23,37 +23,37 @@ use Util;
my $verifier = Wallet::ACL::Base->new;
ok (defined $verifier, 'Wallet::ACL::Base creation');
ok ($verifier->isa ('Wallet::ACL::Base'), ' and class verification');
-is ($verifier->check ('rra@stanford.edu', 'rra@stanford.edu'), 0,
+is ($verifier->check ('eagle@eyrie.org', 'eagle@eyrie.org'), 0,
'Default check declines');
is ($verifier->error, undef, 'No error set');
$verifier = Wallet::ACL::Krb5->new;
ok (defined $verifier, 'Wallet::ACL::Krb5 creation');
ok ($verifier->isa ('Wallet::ACL::Krb5'), ' and class verification');
-is ($verifier->check ('rra@stanford.edu', 'rra@stanford.edu'), 1,
+is ($verifier->check ('eagle@eyrie.org', 'eagle@eyrie.org'), 1,
'Simple check');
-is ($verifier->check ('rra@stanford.edu', 'thoron@stanford.edu'), 0,
+is ($verifier->check ('eagle@eyrie.org', 'thoron@stanford.edu'), 0,
'Simple failure');
is ($verifier->error, undef, 'No error set');
-is ($verifier->check (undef, 'rra@stanford.edu'), undef,
+is ($verifier->check (undef, 'eagle@eyrie.org'), undef,
'Undefined principal');
is ($verifier->error, 'no principal specified', ' and right error');
-is ($verifier->check ('rra@stanford.edu', ''), undef, 'Empty ACL');
+is ($verifier->check ('eagle@eyrie.org', ''), undef, 'Empty ACL');
is ($verifier->error, 'malformed krb5 ACL', ' and right error');
$verifier = Wallet::ACL::Krb5::Regex->new;
isa_ok ($verifier, 'Wallet::ACL::Krb5::Regex', 'krb5-regex verifier');
-is ($verifier->check ('rra@stanford.edu', '.*@stanford\.edu\z'), 1,
+is ($verifier->check ('eagle@eyrie.org', '.*@stanford\.edu\z'), 1,
'Simple check');
-is ($verifier->check ('rra@stanford.edu', '^a.*@stanford\.edu'), 0,
+is ($verifier->check ('eagle@eyrie.org', '^a.*@stanford\.edu'), 0,
'Simple failure');
is ($verifier->error, undef, 'No error set');
is ($verifier->check (undef, '^rra@stanford\.edu\z'), undef,
'Undefined principal');
is ($verifier->error, 'no principal specified', ' and right error');
-is ($verifier->check ('rra@stanford.edu', ''), undef, 'Empty ACL');
+is ($verifier->check ('eagle@eyrie.org', ''), undef, 'Empty ACL');
is ($verifier->error, 'no ACL specified', ' and right error');
-is ($verifier->check ('rra@stanford.edu', '(rra'), undef, 'Malformed regex');
+is ($verifier->check ('eagle@eyrie.org', '(rra'), undef, 'Malformed regex');
is ($verifier->error, 'malformed krb5-regex ACL', ' and right error');
# Tests for the NetDB verifiers. Skip these if we don't have a keytab or if
diff --git a/perl/t/wa-keyring.t b/perl/t/wa-keyring.t
index 7ba5723..eaae034 100755
--- a/perl/t/wa-keyring.t
+++ b/perl/t/wa-keyring.t
@@ -2,7 +2,7 @@
#
# Tests for the WebAuth keyring object implementation.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2013
# The Board of Trustees of the Leland Stanford Junior University
#
diff --git a/perl/Wallet/ACL.pm b/perl/Wallet/ACL.pm
index 15a380f..808be3c 100644
--- a/perl/Wallet/ACL.pm
+++ b/perl/Wallet/ACL.pm
@@ -1,6 +1,6 @@
# Wallet::ACL -- Implementation of ACLs in the wallet system.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2007, 2008, 2010, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -652,6 +652,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::ACL -- Implementation of ACLs in the wallet system.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008, 2010, 2013
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/ACL/Base.pm b/perl/Wallet/ACL/Base.pm
index 5112c2f..b6e4ce3 100644
--- a/perl/Wallet/ACL/Base.pm
+++ b/perl/Wallet/ACL/Base.pm
@@ -1,6 +1,6 @@
# Wallet::ACL::Base -- Parent class for wallet ACL verifiers.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2007, 2010
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -120,6 +120,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::ACL::Base -- Parent class for wallet ACL verifiers.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2010
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/ACL/Krb5.pm b/perl/Wallet/ACL/Krb5.pm
index 716a223..ed0b7df 100644
--- a/perl/Wallet/ACL/Krb5.pm
+++ b/perl/Wallet/ACL/Krb5.pm
@@ -1,6 +1,6 @@
# Wallet::ACL::Krb5 -- Wallet Kerberos v5 principal ACL verifier.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2007, 2010
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -120,6 +120,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::ACL::Krb5 -- Wallet Kerberos v5 principal ACL verifier.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2010
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/ACL/NetDB.pm b/perl/Wallet/ACL/NetDB.pm
index 2d35f49..b76d4ed 100644
--- a/perl/Wallet/ACL/NetDB.pm
+++ b/perl/Wallet/ACL/NetDB.pm
@@ -1,6 +1,6 @@
# Wallet::ACL::NetDB -- Wallet NetDB role ACL verifier.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2007, 2010
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -262,6 +262,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::ACL::NetDB -- Wallet NetDB role ACL verifier.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2010
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/ACL/NetDB/Root.pm b/perl/Wallet/ACL/NetDB/Root.pm
index ea79d79..6c95c6e 100644
--- a/perl/Wallet/ACL/NetDB/Root.pm
+++ b/perl/Wallet/ACL/NetDB/Root.pm
@@ -1,6 +1,6 @@
# Wallet::ACL::NetDB::Root -- Wallet NetDB role ACL verifier (root instances).
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2007, 2010
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -123,6 +123,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::ACL::NetDB::Root -- Wallet NetDB role ACL verifier (root instances).
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2010
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/Admin.pm b/perl/Wallet/Admin.pm
index 3e9c9f5..3a05284 100644
--- a/perl/Wallet/Admin.pm
+++ b/perl/Wallet/Admin.pm
@@ -1,6 +1,6 @@
# Wallet::Admin -- Wallet system administrative interface.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2008, 2009, 2010, 2011, 2012, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -374,6 +374,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::Admin -- Wallet system administrative interface.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2008, 2009, 2010, 2011, 2012, 2013
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/Config.pm b/perl/Wallet/Config.pm
index c3f6d15..0d9d506 100644
--- a/perl/Wallet/Config.pm
+++ b/perl/Wallet/Config.pm
@@ -1,6 +1,6 @@
# Wallet::Config -- Configuration handling for the wallet server.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2007, 2008, 2010, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -776,6 +776,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::Config -- Configuration handling for the wallet server.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008, 2010, 2013
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/Database.pm b/perl/Wallet/Database.pm
index 61de0ba..031be9e 100644
--- a/perl/Wallet/Database.pm
+++ b/perl/Wallet/Database.pm
@@ -5,7 +5,7 @@
# intention is that Wallet::Database objects can be treated in all respects
# like DBIx::Class objects in the rest of the code.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2008, 2009, 2010, 2012, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -118,6 +118,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -5,7 +5,7 @@
# like DBIx::Class objects in the rest of the code.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2008, 2009, 2010, 2012, 2013
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/Kadmin/MIT.pm b/perl/Wallet/Kadmin/MIT.pm
index b633e67..1ae01bf 100644
--- a/perl/Wallet/Kadmin/MIT.pm
+++ b/perl/Wallet/Kadmin/MIT.pm
@@ -1,6 +1,6 @@
# Wallet::Kadmin::MIT -- Wallet Kerberos administration API for MIT.
#
# Written by Russ Allbery <rra@stanford.edu>
# Pulled into a module by Jon Robertson <jonrober@stanford.edu>
# Copyright 2007, 2008, 2009, 2010
# The Board of Trustees of the Leland Stanford Junior University
@@ -318,6 +318,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHORS
-Russ Allbery <rra@stanford.edu> and Jon Robertson <jonrober@stanford.edu>.
+Russ Allbery <eagle@eyrie.org> and Jon Robertson <jonrober@stanford.edu>.
=cut
@@ -1,6 +1,6 @@
# Wallet::Kadmin::MIT -- Wallet Kerberos administration API for MIT.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Pulled into a module by Jon Robertson <jonrober@stanford.edu>
# Copyright 2007, 2008, 2009, 2010
diff --git a/perl/Wallet/Object/Base.pm b/perl/Wallet/Object/Base.pm
index dd128cc..8debac9 100644
--- a/perl/Wallet/Object/Base.pm
+++ b/perl/Wallet/Object/Base.pm
@@ -1,6 +1,6 @@
# Wallet::Object::Base -- Parent class for any object stored in the wallet.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2007, 2008, 2010, 2011
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -1010,6 +1010,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::Object::Base -- Parent class for any object stored in the wallet.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008, 2010, 2011
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/Object/File.pm b/perl/Wallet/Object/File.pm
index 49589f1..4afef04 100644
--- a/perl/Wallet/Object/File.pm
+++ b/perl/Wallet/Object/File.pm
@@ -1,6 +1,6 @@
# Wallet::Object::File -- File object implementation for the wallet.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2008, 2010
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -237,6 +237,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::Object::File -- File object implementation for the wallet.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2008, 2010
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/Object/Keytab.pm b/perl/Wallet/Object/Keytab.pm
index 45d5826..24c3302 100644
--- a/perl/Wallet/Object/Keytab.pm
+++ b/perl/Wallet/Object/Keytab.pm
@@ -1,6 +1,6 @@
# Wallet::Object::Keytab -- Keytab object implementation for the wallet.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2007, 2008, 2009, 2010, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -508,6 +508,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::Object::Keytab -- Keytab object implementation for the wallet.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008, 2009, 2010, 2013
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/Object/WAKeyring.pm b/perl/Wallet/Object/WAKeyring.pm
index f33497c..f8bd0f7 100644
--- a/perl/Wallet/Object/WAKeyring.pm
+++ b/perl/Wallet/Object/WAKeyring.pm
@@ -1,6 +1,6 @@
# Wallet::Object::WAKeyring -- WebAuth keyring object implementation.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2012, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -365,6 +365,6 @@ from <http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::Object::WAKeyring -- WebAuth keyring object implementation.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2012, 2013
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/Policy/Stanford.pm b/perl/Wallet/Policy/Stanford.pm
index 72abd09..8bf4257 100644
--- a/perl/Wallet/Policy/Stanford.pm
+++ b/perl/Wallet/Policy/Stanford.pm
@@ -1,6 +1,6 @@
# Wallet::Policy::Stanford -- Stanford's wallet naming and ownership policy.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2013
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -412,6 +412,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::Policy::Stanford -- Stanford's wallet naming and ownership policy.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2013
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/Report.pm b/perl/Wallet/Report.pm
index b27a998..1085546 100644
--- a/perl/Wallet/Report.pm
+++ b/perl/Wallet/Report.pm
@@ -1,6 +1,6 @@
# Wallet::Report -- Wallet system reporting interface.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2008, 2009, 2010, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -675,6 +675,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu> and Jon Robertson <jonrober@stanford.edu>.
+Russ Allbery <eagle@eyrie.org> and Jon Robertson <jonrober@stanford.edu>.
=cut
@@ -1,6 +1,6 @@
# Wallet::Report -- Wallet system reporting interface.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2008, 2009, 2010, 2013
# The Board of Trustees of the Leland Stanford Junior University
diff --git a/perl/Wallet/Server.pm b/perl/Wallet/Server.pm
index 6d67e17..3266928 100644
--- a/perl/Wallet/Server.pm
+++ b/perl/Wallet/Server.pm
@@ -1,6 +1,6 @@
# Wallet::Server -- Wallet system server implementation.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2007, 2008, 2010, 2011, 2013
# The Board of Trustees of the Leland Stanford Junior University
#
@@ -1090,6 +1090,6 @@ available from L<http://www.eyrie.org/~eagle/software/wallet/>.
=head1 AUTHOR
-Russ Allbery <rra@stanford.edu>
+Russ Allbery <eagle@eyrie.org>
=cut
@@ -1,6 +1,6 @@
# Wallet::Server -- Wallet system server implementation.
#
-# Written by Russ Allbery <rra@stanford.edu>
+# Written by Russ Allbery <eagle@eyrie.org>
# Copyright 2007, 2008, 2010, 2011, 2013
# The Board of Trustees of the Leland Stanford Junior University